==> nextcloud-app-mail-4.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/pt_PT.js <==
OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Mensagem embebida %s",
    "Important mail" : "Mensagem importante",
    "Set up an account" : "Configurar uma conta",
    "Unread mail" : "Mensagem por ler",
    "Important" : "Importante",
    "Work" : "Profissional",
    "Personal" : "Pessoal",
    "To Do" : "A fazer",
    "Later" : "Mais tarde",
    "Mail" : "Correio",
    "Mails" : "Mensagens",
    "💌 A mail app for Nextcloud" : "Uma aplicação de correio electrónico para Nextcloud",
    "Drafts are saved in:" : "Os rascunhos são guardados em:",
    "Sent messages are saved in:" : "As mensagens enviadas são guardadas em:",
    "Deleted messages are moved in:" : "Deleted messages are moved in:",
    "Auto" : "Auto",
    "Name" : "Nome",
    "Password" : "Palavra-passe",
    "Manual" : "Manual",
    "IMAP Settings" : "Definições IMAP",
    "IMAP Host" : "Anfitrião de IMAP",
    "IMAP Security" : "Segurança IMAP",
    "None" : "Nenhum",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Porto IMAP",
    "IMAP User" : "Utilizador IMAP",
    "IMAP Password" : "Palavra-passe IMAP",
    "SMTP Settings" : "Definições SMTP",
    "SMTP Host" : "Anfitrião de SMTP",
    "SMTP Security" : "Segurança SMTP",
    "SMTP Port" : "Porto SMTP",
    "SMTP User" : "Utilizador SMTP",
    "SMTP Password" : "Palavra-passe SMTP",
    "Connecting" : "A conectar",
    "Save" : "Guardar",
    "Connect" : "Ligar",
    "Password required" : "Necessário palavra-passe",
    "Account settings" : "Definições da conta",
    "Signature" : "Assinatura",
    "A signature is added to the text of new messages and replies." : "A assinatura é adicionada ao texto das novas mensagens e respostas.",
    "Writing mode" : "Modo de escrita",
    "Preferred writing mode for new messages and replies." : "Modo de escrita pré definido para novas mensagens e respostas.",
    "Default folders" : "Pastas pré definidas",
    "Mail server" : "Servidor de correio electrónico",
    "Go back" : "Voltar",
    "Change name" : "Alterar nome",
    "Email address" : "Endereço de email",
    "Add alias" : "Adicionar alcunha",
    "Cancel" : "Cancelar",
    "Add mail account" : "Adicionar conta de email",
    "General" : "Geral",
    "List" : "Lista",
    "Use Gravatar and favicon avatars" : "Usar Gravatar e favicon avatars",
    "Register as application for mail links" : "Registar como aplicação para ligações de correio",
    "Register" : "Registar",
    "Trusted senders" : "Remetentes confiáveis",
    "Keyboard shortcuts" : "Atalhos de teclado",
    "Compose new message" : "Compor nova mensagem",
    "Archive" : "Arquivar",
    "Delete" : "Eliminar",
    "Search" : "Pesquisar",
    "Send" : "Enviar",
    "Refresh" : "Atualizar",
    "From" : "De",
    "Select account" : "Seleccionar uma conta",
    "To" : "Para",
    "Contact or email address …" : "Contacto ou endereço de email",
    "Cc" : "Cc",
    "Bcc" : "Bcc",
    "Subject" : "Assunto",
    "Subject …" : "Assunto...",
    "Write message …" : "Nova mensagem...",
    "Saving draft …" : "A guardar rascunho ...",
    "Draft saved" : "Rascunho guardado",
    "Enable formatting" : "Activar formatação",
    "Upload attachment" : "Carregar anexo",
    "Add attachment from Files" : "Adicionar anexo a partir dos ficheiros",
    "Request a read receipt" : "Solicitar um recibo de leitura",
    "Encrypt message with Mailvelope" : "Cifrar a mensagem com Mailvelope",
    "Choose a file to add as attachment" : "Escolha um ficheiro para adicionar como anexo",
    "Choose" : "Escolher",
    "Confirm" : "Confirmar",
    "Plain text" : "Texto simples",
    "No messages" : "Sem mensagens",
    "Draft: " : "Rascunho:",
    "Unfavorite" : "Não favorito",
    "Favorite" : "Favorito",
    "Read" : "Ler",
    "Mark as spam" : "Marcar como spam",
    "Unselect" : "Não selecionar",
    "Select" : "Seleccionar",
    "Edit tags" : "Editar etiquetas",
    "More actions" : "Mais acções",
    "Back" : "Anterior",
    "Edit as new message" : "Editar como nova mensagem",
    "Create event" : "Criar evento",
    "Could not delete message" : "Não foi possível apagar a mensagem",
    "Forward" : "Encaminhar",
    "Load more" : "Carregar mais",
    "All day" : "Todo o dia",
    "Description" : "Descrição",
    "Create" : "Criar",
    "Could not create event" : "Não foi possível criar o evento",
    "Comment" : "Comentário",
    "Accept" : "Aceitar",
    "Decline" : "Recusar",
    "domain" : "domínio",
    "Remove" : "Remover",
    "email" : "email",
    "individual" : "individual",
    "Important info" : "Informação importante",
    "Other" : "Outro",
    "Notify the sender" : "Notificar o remetente",
    "View source" : "Ver fonte",
    "Message body" : "Corpo da mensagem",
    "Choose a folder to store the attachment in" : "Escolha uma pasta para guardar o anexo",
    "Import into calendar" : "Importar para o calendário",
    "Download attachment" : "Transferir anexo",
    "Save to Files" : "Guardar em Ficheiros",
    "Unnamed" : "Sem nome",
    "Embedded message" : "Mensagem embebida",
    "Choose a folder to store the attachments in" : "Escolha uma pasta para armazenar anexos",
    "Save all to Files" : "Guardar todos em Ficheiros",
    "Download Zip" : "Transferir Zip",
    "The images have been blocked to protect your privacy." : "As imagens foram bloqueadas para proteger a sua privacidade.",
    "Show images" : "Mostrar imagens",
    "Show images temporarily" : "Mostrar imagens temporariamente",
    "Always show images from {sender}" : "Mostrar sempre as imagem de {sender}",
    "Always show images from {domain}" : "Mostrar sempre as imagem de {domain}",
    "Move" : "Mover",
    "Moving" : "A mover",
    "Quota" : "Quota",
    "Add mailbox" : "Adicionar caixa de",
    "Saving" : "A guardar",
    "Move up" : "Mover para cima",
    "Move down" : "Mover para baixo",
    "Remove account" : "Remover conta",
    "Loading …" : "A carregar...",
    "Not supported by the server" : "Não é suportado pelo servidor",
    "{usage} of {limit} used" : "Usado {usage}  {limit}",
    "Remove {email}" : "Remover {email}",
    "Show all mailboxes" : "Mostrar todas as caixas de entrada",
    "Mark all as read" : "Marcar todas como lidas",
    "Rename" : "Renomear",
    "Clear cache" : "Limpar cache",
    "Clear locally cached data, in case there are issues with synchronization." : "Limpe a cache de dados local no caso de ter problemas com a sincronização.",
    "Subscribed" : "Subscrito",
    "New message" : "Nova mensagem",
    "Error sending your message" : "Erro ao enviar a sua mensagem",
    "Retry" : "Repetir",
    "Uploading attachments …" : "A enviar anexos ...",
    "Sending …" : "A enviar...",
    "Warning sending your message" : "Aviso ao enviar a sua mensagem",
    "Send anyway" : "Enviar de qualquer maneira",
    "Reply" : "Resposta",
    "Message" : "Mensagem",
    "Contacts with this address" : "Contactos com este endereço",
    "Add to Contact" : "Adicionar aos contactos",
    "New Contact" : "Novo contacto",
    "Copy to clipboard" : "Copiar para área de transferência",
    "Contact name …" : "Nome do contacto...",
    "Add" : "Adicionar",
    "Close" : "Fechar",
    "Body" : "Corpo",
    "Date" : "Data",
    "Tags" : "Etiquetas",
    "Clear" : "Limpar",
    "Custom" : "Personalizado",
    "Signature …" : "Assinatura...",
    "Save signature" : "Guardar assinatura",
    "Tag already exists" : "A etiqueta já existe",
    "Not found" : "Não foi encontrado",
    "Reply to sender only" : "Resposta apenas ao remetente",
    "Message source" : "Fonte da mensagem",
    "Import into {calendar}" : "Importar para {calendar}",
    "Event imported into {calendar}" : "Evento importado para {calendar}",
    "Airplane" : "Avião",
    "Reservation {id}" : "Reserva {id}",
    "Train" : "Comboio",
    "Operator" : "Operador",
    "Actions" : "Acções",
    "New action" : "Nova ação",
    "Priority" : "Prioridade",
    "Reset" : "Reiniciar",
    "Client ID" : "Id. do Cliente",
    "Client secret" : "Segredo do cliente\\\\",
    "Email: {email}" : "Email: {email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} em {host}:{port} ({ssl} encryption)",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} em {host}:{port} ({ssl} encryption)",
    "IMAP" : "IMAP",
    "User" : "Utilizador",
    "Host" : "Anfitrião",
    "Port" : "Porta",
    "SMTP" : "SMTP",
    "Valid until" : "Válido até",
    "Certificate" : "Certificado",
    "Submit" : "Submeter",
    "Account connected" : "Conta ligada",
    "Connect your mail account" : "Ligue a sua conta de e-mail",
    "All" : "Todos",
    "Drafts" : "Rascunhos",
    "Favorites" : "Favoritos",
    "Priority inbox" : "Caixa de entrada prioritária",
    "All inboxes" : "Todas as caixas de entrada",
    "Inbox" : "Caixa de Entrada",
    "Junk" : "Lixo",
    "Sent" : "Enviada",
    "Trash" : "Reciclagem",
    "Error while sharing file" : "Erro ao partilhar ficheiro",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Could not load {tag}{name}{endtag}" : "Não foi possível carregar {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Ocorreu um problema ao carregar {tag}{name}{endtag}",
    "Could not load your message" : "Não foi possível carregar a sua mensagem",
    "Could not load the desired message" : "Não foi possível carregar a mensagem escolhida",
    "Could not load the message" : "Não foi possível carregar a mensagem",
    "Error loading message" : "Erro ao carregar a mensagem",
    "Forwarding to %s" : "A reencaminhar para %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Clique aqui se não for automaticamente redireccionado dentro de segundos.",
    "Redirect" : "Redirecionar",
    "The link leads to %s" : "A ligação aponta para %s",
    "Continue to %s" : "Continuar para %s"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-app-mail-4.1.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/pt_PT.js <==
OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Mensagem embebida %s",
    "Important mail" : "Mensagem importante",
    "Set up an account" : "Configurar uma conta",
    "Unread mail" : "Mensagem por ler",
    "Important" : "Importante",
    "Work" : "Profissional",
    "Personal" : "Pessoal",
    "To Do" : "A fazer",
    "Later" : "Mais tarde",
    "Mail" : "Correio",
    "Mails" : "Mensagens",
    "💌 A mail app for Nextcloud" : "Uma aplicação de correio electrónico para Nextcloud",
    "Drafts are saved in:" : "Os rascunhos são guardados em:",
    "Sent messages are saved in:" : "As mensagens enviadas são guardadas em:",
    "Deleted messages are moved in:" : "Deleted messages are moved in:",
    "Auto" : "Auto",
    "Name" : "Nome",
    "Password" : "Palavra-passe",
    "Manual" : "Manual",
    "IMAP Settings" : "Definições IMAP",
    "IMAP Host" : "Anfitrião de IMAP",
    "IMAP Security" : "Segurança IMAP",
    "None" : "Nenhum",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Porto IMAP",
    "IMAP User" : "Utilizador IMAP",
    "IMAP Password" : "Palavra-passe IMAP",
    "SMTP Settings" : "Definições SMTP",
    "SMTP Host" : "Anfitrião de SMTP",
    "SMTP Security" : "Segurança SMTP",
    "SMTP Port" : "Porto SMTP",
    "SMTP User" : "Utilizador SMTP",
    "SMTP Password" : "Palavra-passe SMTP",
    "Connecting" : "A ligar",
    "Reconnect Google account" : "Religar conta Google",
    "Reconnect Microsoft account" : "Religar conta Microsoft",
    "Save" : "Guardar",
    "Connect" : "Ligar",
    "Password required" : "Necessário palavra-passe",
    "Account settings" : "Definições da conta",
    "Signature" : "Assinatura",
    "A signature is added to the text of new messages and replies." : "A assinatura é adicionada ao texto das novas mensagens e respostas.",
    "Writing mode" : "Modo de escrita",
    "Preferred writing mode for new messages and replies." : "Modo de escrita pré definido para novas mensagens e respostas.",
    "Default folders" : "Pastas pré definidas",
    "Mail server" : "Servidor de correio electrónico",
    "Go back" : "Voltar",
    "Change name" : "Alterar nome",
    "Email address" : "Endereço de email",
    "Add alias" : "Adicionar alcunha",
    "Cancel" : "Cancelar",
    "Add mail account" : "Adicionar conta de email",
    "General" : "Geral",
    "List" : "Lista",
    "Use Gravatar and favicon avatars" : "Usar Gravatar e favicon avatars",
    "Register as application for mail links" : "Registar como aplicação para ligações de correio",
    "Register" : "Registar",
    "Trusted senders" : "Remetentes confiáveis",
    "Keyboard shortcuts" : "Atalhos de teclado",
    "Compose new message" : "Compor nova mensagem",
    "Archive" : "Arquivar",
    "Delete" : "Eliminar",
    "Search" : "Pesquisar",
    "Send" : "Enviar",
    "Refresh" : "Atualizar",
    "From" : "De",
    "Select account" : "Seleccionar uma conta",
    "To" : "Para",
    "Contact or email address …" : "Contacto ou endereço de email",
    "Cc" : "Cc",
    "Bcc" : "Bcc",
    "Subject" : "Assunto",
    "Subject …" : "Assunto...",
    "Write message …" : "Nova mensagem...",
    "Saving draft …" : "A guardar rascunho ...",
    "Draft saved" : "Rascunho guardado",
    "Enable formatting" : "Activar formatação",
    "Upload attachment" : "Carregar anexo",
    "Add attachment from Files" : "Adicionar anexo a partir dos ficheiros",
    "Request a read receipt" : "Solicitar um recibo de leitura",
    "Encrypt message with Mailvelope" : "Cifrar a mensagem com Mailvelope",
    "Choose a file to add as attachment" : "Escolha um ficheiro para adicionar como anexo",
    "Choose" : "Escolher",
    "Confirm" : "Confirmar",
    "Plain text" : "Texto simples",
    "No messages" : "Sem mensagens",
    "Draft: " : "Rascunho:",
    "Unfavorite" : "Não favorito",
    "Favorite" : "Favorito",
    "Read" : "Ler",
    "Mark as spam" : "Marcar como spam",
    "Edit tags" : "Editar etiquetas",
    "More actions" : "Mais acções",
    "Back" : "Anterior",
    "Edit as new message" : "Editar como nova mensagem",
    "Create event" : "Criar evento",
    "Download message" : "Transferir mensagem",
    "Could not delete message" : "Não foi possível apagar a mensagem",
    "Load more" : "Carregar mais",
    "All day" : "Todo o dia",
    "Description" : "Descrição",
    "Create" : "Criar",
    "Could not create event" : "Não foi possível criar o evento",
    "Select" : "Seleccionar",
    "Comment" : "Comentário",
    "Accept" : "Aceitar",
    "Decline" : "Recusar",
    "domain" : "domínio",
    "Remove" : "Remover",
    "email" : "email",
    "individual" : "individual",
    "Important info" : "Informação importante",
    "Other" : "Outro",
    "Notify the sender" : "Notificar o remetente",
    "Forward" : "Encaminhar",
    "View source" : "Ver fonte",
    "Message body" : "Corpo da mensagem",
    "Choose a folder to store the attachment in" : "Escolha uma pasta para guardar o anexo",
    "Import into calendar" : "Importar para o calendário",
    "Download attachment" : "Transferir anexo",
    "Save to Files" : "Guardar em Ficheiros",
    "Unnamed" : "Sem nome",
    "Embedded message" : "Mensagem embebida",
    "Choose a folder to store the attachments in" : "Escolha uma pasta para armazenar anexos",
    "Save all to Files" : "Guardar todos em Ficheiros",
    "Download Zip" : "Transferir Zip",
    "The images have been blocked to protect your privacy." : "As imagens foram bloqueadas para proteger a sua privacidade.",
    "Show images" : "Mostrar imagens",
    "Show images temporarily" : "Mostrar imagens temporariamente",
    "Always show images from {sender}" : "Mostrar sempre as imagem de {sender}",
    "Always show images from {domain}" : "Mostrar sempre as imagem de {domain}",
    "Move" : "Mover",
    "Moving" : "A mover",
    "Quota" : "Quota",
    "Add mailbox" : "Adicionar caixa de",
    "Saving" : "A guardar",
    "Move up" : "Mover para cima",
    "Move down" : "Mover para baixo",
    "Remove account" : "Remover conta",
    "Loading …" : "A carregar...",
    "Not supported by the server" : "Não é suportado pelo servidor",
    "{usage} of {limit} used" : "Usado {usage}  {limit}",
    "Remove {email}" : "Remover {email}",
    "Show all mailboxes" : "Mostrar todas as caixas de entrada",
    "Mark all as read" : "Marcar todas como lidas",
    "Rename" : "Renomear",
    "Clear cache" : "Limpar cache",
    "Clear locally cached data, in case there are issues with synchronization." : "Limpe a cache de dados local no caso de ter problemas com a sincronização.",
    "Subscribed" : "Subscrito",
    "New message" : "Nova mensagem",
    "Error sending your message" : "Erro ao enviar a sua mensagem",
    "Retry" : "Repetir",
    "Uploading attachments …" : "A enviar anexos ...",
    "Sending …" : "A enviar...",
    "Warning sending your message" : "Aviso ao enviar a sua mensagem",
    "Send anyway" : "Enviar de qualquer maneira",
    "Reply" : "Resposta",
    "Message" : "Mensagem",
    "Contacts with this address" : "Contactos com este endereço",
    "Add to Contact" : "Adicionar aos contactos",
    "New Contact" : "Novo contacto",
    "Copy to clipboard" : "Copiar para área de transferência",
    "Contact name …" : "Nome do contacto...",
    "Add" : "Adicionar",
    "Close" : "Fechar",
    "Body" : "Corpo",
    "Date" : "Data",
    "Tags" : "Etiquetas",
    "Clear" : "Limpar",
    "Custom" : "Personalizado",
    "Signature …" : "Assinatura...",
    "Save signature" : "Guardar assinatura",
    "Tag already exists" : "A etiqueta já existe",
    "Not found" : "Não foi encontrado",
    "Reply to sender only" : "Resposta apenas ao remetente",
    "Message source" : "Fonte da mensagem",
    "Import into {calendar}" : "Importar para {calendar}",
    "Event imported into {calendar}" : "Evento importado para {calendar}",
    "Airplane" : "Avião",
    "Reservation {id}" : "Reserva {id}",
    "Train" : "Comboio",
    "Operator" : "Operador",
    "Actions" : "Acções",
    "New action" : "Nova ação",
    "Priority" : "Prioridade",
    "Reset" : "Reiniciar",
    "Client ID" : "Id. do Cliente",
    "Client secret" : "Segredo do cliente\\\\",
    "Email: {email}" : "Email: {email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} em {host}:{port} ({ssl} encryption)",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} em {host}:{port} ({ssl} encryption)",
    "IMAP" : "IMAP",
    "User" : "Utilizador",
    "Host" : "Anfitrião",
    "Port" : "Porta",
    "SMTP" : "SMTP",
    "Valid until" : "Válido até",
    "Certificate" : "Certificado",
    "Submit" : "Submeter",
    "Account connected" : "Conta ligada",
    "Connect your mail account" : "Ligue a sua conta de e-mail",
    "All" : "Todos",
    "Drafts" : "Rascunhos",
    "Favorites" : "Favoritos",
    "Priority inbox" : "Caixa de entrada prioritária",
    "All inboxes" : "Todas as caixas de entrada",
    "Inbox" : "Caixa de Entrada",
    "Junk" : "Lixo",
    "Sent" : "Enviada",
    "Trash" : "Reciclagem",
    "Error while sharing file" : "Erro ao partilhar ficheiro",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Could not load {tag}{name}{endtag}" : "Não foi possível carregar {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Ocorreu um problema ao carregar {tag}{name}{endtag}",
    "Could not load your message" : "Não foi possível carregar a sua mensagem",
    "Could not load the desired message" : "Não foi possível carregar a mensagem escolhida",
    "Could not load the message" : "Não foi possível carregar a mensagem",
    "Error loading message" : "Erro ao carregar a mensagem",
    "Forwarding to %s" : "A reencaminhar para %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Clique aqui se não for automaticamente redireccionado dentro de segundos.",
    "Redirect" : "Redirecionar",
    "The link leads to %s" : "A ligação aponta para %s",
    "Continue to %s" : "Continuar para %s",
    "Unselect" : "Não selecionar"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
